# Build -python subpackage
%bcond_without python
# Build -java subpackage
%bcond_without java
# Don't require gtest
%bcond_with gtest

# Major
%define major           7

# Library names
%define libname         %mklibname %{name} %{major}
%define liblite         %mklibname %{name}-lite %{major}
%define libcompiler     %mklibname protoc %{major}
%define develname       %mklibname %{name} -d
%define staticdevelname %mklibname %{name} -d -s


%if %{with python}
%define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")
%endif

Summary:        Protocol Buffers - Google's data interchange format
Name:           protobuf
Version:        2.4.1
Release:        %mkrel 5
License:        BSD
Group:          Development/Other
Source:         http://protobuf.googlecode.com/files/%{name}-%{version}.tar.bz2
Source1:        ftdetect-proto.vim
Patch1:		protobuf-2.3.0-fedora-gtest.patch
Patch2:		protobuf-java-fixes.patch
URL:            http://code.google.com/p/protobuf/
BuildRequires:  automake autoconf libtool pkgconfig 
%if %{with gtest}
BuildRequires:  gtest-devel
%endif
BuildRequires:  zlib-devel

%description
Protocol Buffers are a way of encoding structured data in an efficient
yet extensible format. Google uses Protocol Buffers for almost all of
its internal RPC protocols and file formats.

Protocol buffers are a flexible, efficient, automated mechanism for
serializing structured data – think XML, but smaller, faster, and
simpler. You define how you want your data to be structured once, then
you can use special generated source code to easily write and read
your structured data to and from a variety of data streams and using a
variety of languages. You can even update your data structure without
breaking deployed programs that are compiled against the "old" format.

%package -n             %{libname}
Summary:                Runtime library for %{name}
Group:                  System/Libraries
Obsoletes:		%{_lib}protobuf6 < %{version}-%{release}

%description -n         %{libname}
Protocol Buffers are a way of encoding structured data in an efficient
yet extensible format. Google uses Protocol Buffers for almost all of
its internal RPC protocols and file formats.

Protocol buffers are a flexible, efficient, automated mechanism for
serializing structured data - think XML, but smaller, faster, and
simpler. You define how you want your data to be structured once, then
you can use special generated source code to easily write and read
your structured data to and from a variety of data streams and using a
variety of languages. You can even update your data structure without
breaking deployed programs that are compiled against the "old" format.

This package contains the shared %{name} library.

%package -n             %{liblite}
Summary:                Protocol Buffers lite version
Group:                  Development/Other
Obsoletes:		%{_lib}protobuf-lite6 < %{version}-%{release}

%description -n         %{liblite}
This package contains a compiled with "optimize_for = LITE_RUNTIME"
version of Google's Protocol Buffers library.

The "optimize_for = LITE_RUNTIME" option causes the compiler to
generate code which only depends libprotobuf-lite, which is much
smaller than libprotobuf but lacks descriptors, reflection, and some
other features.

%package                compiler
Summary:                Protocol Buffers compiler
Group:                  Development/Other
Suggests:               %{libname} = %{version}
Suggests:               %{liblite} = %{version}

%description            compiler
This package contains Protocol Buffers compiler for all programming
languages.

%package -n             %{libcompiler}
Summary:                Protocol Buffers compiler shared library
Group:                  System/Libraries
Obsoletes:		%{_lib}protoc6 < %{version}-%{release}

%description -n         %{libcompiler}
This package contains the Protocol Buffers compiler shared library.

%package -n             %{develname}
Summary:                Protocol Buffers C++ headers and libraries
Group:                  Development/Other
Requires:               %{libname} = %{version}
Requires:               %{liblite} = %{version}
Requires:		%{libcompiler} = %{version}
Requires:               %{name}-compiler = %{version}
Provides:               %{name}-devel = %{version}-%{release}

%description -n         %{develname}
This package contains Protocol Buffers compiler for all languages and
C++ headers and libraries.

%package -n             %{staticdevelname}
Summary:                Static development files for %{name}
Group:                  Development/Other
Requires:		%{develname} = %{version}
Provides:               %{name}-static-devel = %{version}-%{release}

%description -n         %{staticdevelname}
This package contains static libraries for Protocol Buffers.

%if %{with python}
%package -n python-%name
Summary: Python bindings for Google Protocol Buffers
Group: Development/Python
BuildRequires: python-devel
BuildRequires: python-setuptools
Obsoletes:     %name-python < 2.3.1
Provides:      %name-python = %version-%release
Conflicts: %{name}-compiler > %{version}
Conflicts: %{name}-compiler < %{version}

%description -n python-%name
This package contains Python libraries for Google Protocol Buffers
%endif

%package vim
Summary: Vim syntax highlighting for Google Protocol Buffers descriptions
Group: Development/Other
BuildArch: noarch
Requires: vim-enhanced

%description vim
This package contains syntax highlighting for Google Protocol Buffers
descriptions in Vim editor

%if %{with java}
%package java
Summary: Java Protocol Buffers runtime library
Group:   Development/Java
BuildArch:	noarch
BuildRequires:    java-devel >= 1.6
BuildRequires:    jpackage-utils
BuildRequires:    maven
BuildRequires:    maven-compiler-plugin
BuildRequires:    maven-install-plugin
BuildRequires:    maven-jar-plugin
BuildRequires:    maven-javadoc-plugin
BuildRequires:    maven-resources-plugin
BuildRequires:    maven-surefire-plugin
BuildRequires:    maven-antrun-plugin
BuildRequires:    maven-doxia
BuildRequires:    maven-doxia-sitetools
Requires:         java
Requires:         jpackage-utils
Requires(post):   jpackage-utils
Requires(postun): jpackage-utils
Conflicts:        %{name}-compiler > %{version}
Conflicts:        %{name}-compiler < %{version}

%description java
This package contains Java Protocol Buffers runtime library.

%package javadoc
Summary: Javadocs for %{name}-java
Group:   Development/Java
BuildArch: noarch
Requires: jpackage-utils
Requires: %{name}-java = %{version}-%{release}

%description javadoc
This package contains the API documentation for %{name}-java.

%endif

%prep
%setup -q
%if %{with gtest}
rm -rf gtest
%patch1 -p1
%endif
chmod 644 examples/*
%if %{with java}
%patch2 -p1
rm -rf java/src/test
%endif

%build
iconv -f iso8859-1 -t utf-8 CONTRIBUTORS.txt > CONTRIBUTORS.txt.utf8
mv CONTRIBUTORS.txt.utf8 CONTRIBUTORS.txt
export PTHREAD_LIBS="-lpthread"
./autogen.sh
%configure2_5x

%make

%if %{with python}
pushd python
python ./setup.py build
sed -i -e 1d build/lib/google/protobuf/descriptor_pb2.py
popd
%endif

%if %{with java}
pushd java
mvn-rpmbuild install javadoc:javadoc
popd
%endif

%check
#make check

%install
%make install DESTDIR=%{buildroot} STRIPBINARIES=no INSTALL="%{__install} -p" CPPROG="cp -p"
find %{buildroot} -type f -name "*.la" -exec rm -f {} \;

%if %{with python}
pushd python
python ./setup.py install --root=%{buildroot} --single-version-externally-managed --record=INSTALLED_FILES --optimize=1
popd
%endif
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_datadir}/vim/vimfiles/ftdetect/proto.vim
install -p -m 644 -D editors/proto.vim %{buildroot}%{_datadir}/vim/vimfiles/syntax/proto.vim

%if %{with java}
pushd java
install -d -m 755 %{buildroot}%{_javadir}
install -pm 644 target/%{name}-java-%{version}.jar %{buildroot}%{_javadir}/%{name}.jar

install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -rp target/site/apidocs %{buildroot}%{_javadocdir}/%{name}

install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{name}.pom
%add_maven_depmap JPP-%{name}.pom %{name}.jar
%endif

%files -n               %{libname}
%doc CHANGES.txt CONTRIBUTORS.txt COPYING.txt README.txt
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{major}.*

%files -n               %{liblite}
%doc COPYING.txt README.txt
%{_libdir}/lib%{name}-lite.so.%{major}
%{_libdir}/lib%{name}-lite.so.%{major}.*

%files                  compiler
%doc COPYING.txt README.txt
%{_bindir}/protoc

%files -n               %{libcompiler}
%{_libdir}/libprotoc.so.%{major}
%{_libdir}/libprotoc.so.%{major}.*

%files -n               %{develname}
%doc examples/add_person.cc examples/addressbook.proto
%doc  examples/list_people.cc examples/Makefile examples/README.txt
%dir %{_includedir}/google
%{_includedir}/google/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}-lite.so
%{_libdir}/libprotoc.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-lite.pc

%files -n               %{staticdevelname}
%{_libdir}/lib%{name}.a
%{_libdir}/lib%{name}-lite.a
%{_libdir}/libprotoc.a

%if %{with python}
%files -n python-%name
%dir %{python_sitelib}/google
%{python_sitelib}/google/protobuf/
%{python_sitelib}/protobuf-%{version}-py2.?.egg-info/
%{python_sitelib}/protobuf-%{version}-py2.?-nspkg.pth
%doc python/README.txt 
%doc examples/add_person.py examples/list_people.py examples/addressbook.proto
%endif

%files vim
%{_datadir}/vim/vimfiles/ftdetect/proto.vim
%{_datadir}/vim/vimfiles/syntax/proto.vim

%if %{with java}
%files java
%{_mavenpomdir}/JPP-protobuf.pom
%{_mavendepmapfragdir}/protobuf
%{_javadir}/%{name}.jar
%doc examples/AddPerson.java examples/ListPeople.java

%files javadoc
%{_javadocdir}/%{name}
%endif


%changelog

* Tue Jan 29 2013 oden <oden> 2.4.1-5.mga3
+ Revision: 393188
- duh!, fix the problem properly (br: zlib-devel)

* Tue Jan 29 2013 oden <oden> 2.4.1-4.mga3
+ Revision: 393180
- fix build
- add one missing header

* Sun Jan 13 2013 umeabot <umeabot> 2.4.1-3.mga3
+ Revision: 378251
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 26 2012 fwang <fwang> 2.4.1-2.mga3
+ Revision: 310142
- sync with fedora spec

* Fri Oct 26 2012 fwang <fwang> 2.4.1-1.mga3
+ Revision: 310125
- disable check till gcc 4.7 problem fixed
- use mvn
- cleanup spec and lock libmajor

* Fri Nov 18 2011 pterjan <pterjan> 2.4.1-1.mga2
+ Revision: 168995
- Fix groups
- Update to 2.4.1

* Fri May 20 2011 dmorgan <dmorgan> 2.3.0-11.mga1
+ Revision: 99925
- Define the major
- Sync packages names with mandriva ( better libification)

* Thu Apr 28 2011 dmorgan <dmorgan> 2.3.0-10.mga1
+ Revision: 93342
- Rename python package name

  + pterjan <pterjan>
    - Drop ldconfig scriptlets

* Thu Apr 28 2011 dmorgan <dmorgan> 2.3.0-9.mga1
+ Revision: 93292
- Rebuild because of missing python package

* Wed Apr 27 2011 dmorgan <dmorgan> 2.3.0-8.mga1
+ Revision: 91988
- Rebuild after bootstrapping
- imported package protobuf

